@@ -58,6 +58,9 @@
 
 #ifdef	W32
 #include <windows.h>
+#ifndef	ssize_t
+#define	ssize_t	long
+#endif
 #else
 #include <cstddef>
 #include <cstdlib>
@@ -764,6 +767,70 @@ public:
 	virtual ~AudioTone();
 };
 
+/**
+ * AudioBase base class for many other audio classes which stream
+ * data.
+ *
+ * @short common audio stream base.
+ */
+class __EXPORT AudioBase : public Audio
+{
+protected:
+	Info info;
+
+public:
+	/**
+	 * Create audio base object with no info.
+	 */
+	AudioBase();
+
+	/**
+	 * Create audio base object with audio source description.
+	 *
+	 * @param source description.
+	 */
+	AudioBase(Info *i);
+
+	/**
+	 * Destroy an audio base object.
+	 */
+	virtual ~AudioBase();
+
+	/**
+	 * Generic get encoding.
+	 *
+	 * @return audio encoding of this object.
+	 */
+	inline Encoding getEncoding(void)
+        	{return info.encoding;};
+
+	/**
+	 * Generic sample rate.
+	 *
+	 * @return audio sample rate of this object.
+	 */
+	inline unsigned getSampleRate(void)
+        	{return info.rate;};
+
+	/**
+	 * Abstract interface to put raw data.
+	 *
+	 * @param address of data to put.
+	 * @param size of data to put.
+	 * @param number of bytes actually put.
+	 */
+	virtual ssize_t putBuffer(Encoded data, size_t) = 0;
+
+        /**
+         * Abstract interface to get raw data.
+         *
+         * @param address of data to get.
+         * @param size of data to get.
+         * @param number of bytes actually received.
+         */
+	virtual ssize_t getBuffer(Encoded data, size_t) = 0;
+};
+	
 /**
  * The AudioBuffer class is for mixing one-to-one
  * soft joins.
@@ -771,11 +838,11 @@ public:
  * @author Mark Lipscombe <markl@gasupnow.com>
  * @short audio buffer mixer class
  */
-class __EXPORT AudioBuffer
+class __EXPORT AudioBuffer : public AudioBase
 {
 public:
-        AudioBuffer(unsigned size = 4096);
-        ~AudioBuffer();
+        AudioBuffer(Info *info, size_t size = 4096);
+        virtual ~AudioBuffer();
 
 	/**
 	 * save audio buffer data.
@@ -783,7 +850,7 @@ public:
 	 * @param address of data save buffer.
 	 * @param number of bytes to save.
 	 */
-        void getBuffer(char *data, unsigned amount);
+        ssize_t getBuffer(Encoded data, size_t amount);
 
 	/**
 	 * Put data into the audio buffer.
@@ -791,13 +858,11 @@ public:
 	 * @param address of data to load.
 	 * @param number of bytes to load.
 	 */
-        void putBuffer(const char *data, unsigned amount);
+        ssize_t putBuffer(Encoded data, size_t amount);
 
 private:
         char *buf;
-        unsigned len;
-        unsigned start;
-        unsigned size;
+        size_t size, start, len;
 	void *mutexObject;
 
 	void enter(void);
@@ -812,12 +877,11 @@ private:
  * @author David Sugar <dyfet@ostel.com>
  * @short audio file access.
  */
-class __EXPORT AudioFile: public Audio
+class __EXPORT AudioFile: public AudioBase
 {
 protected:
 	char *pathname;
 	Error error;
-	Info info;
 	unsigned long header;		// offset to start of audio
 	unsigned long minimum;		// minimum sample size required
 	unsigned long length;           // current size of file, including header
@@ -1039,7 +1103,7 @@ public:
 	 * @return The number of bytes (not samples) read.  Returns -1
 	 * if no bytes are read and an error occurs.
 	 */
-	int getBuffer(void *addr, unsigned len = 0);
+	ssize_t getBuffer(Encoded addr, size_t len = 0);
 
 	/**
 	 * Retrieve and convert content to linear encoded audio data
@@ -1063,7 +1127,7 @@ public:
 	 * @return The number of bytes (not samples) read.  Returns -1
 	 * if an error occurs and no bytes are written.
 	 */
-	int putBuffer(void *attr, unsigned len = 0);
+	ssize_t putBuffer(Encoded attr, size_t len = 0);
 
         /**
          * Convert and store content from linear encoded audio data
@@ -1615,10 +1679,9 @@ public:
 		{return info;};
 };
 
-class __EXPORT AudioDevice : public Audio
+class __EXPORT AudioDevice : public AudioBase
 {
 protected:
-	Info info;
 	bool enabled;
 
 public:
@@ -1650,8 +1713,7 @@ public:
 	 * @param number of encoded bytes to play.
 	 * @return number of encoded bytes played.
 	 */
-	virtual unsigned putEncoded(Encoded data, unsigned len)
-		{return 0;};
+	virtual ssize_t putBuffer(Encoded data, size_t len);
 
         /**  
          * Record audio encoded in the currently selected encoding for
@@ -1661,8 +1723,7 @@ public:
          * @param number of encoded bytes to record.
          * @return number of encoded bytes recorded.
          */
-	virtual unsigned getEncoded(Encoded data, unsigned len)
-		{return 0;};
+	virtual ssize_t getBuffer(Encoded data, unsigned len);
 
 	/**
 	 * Use encoding source descriptor to select the audio encoding
