@@ -40,7 +40,8 @@
 
 using namespace ost;
 
-AudioBuffer::AudioBuffer(unsigned sz)
+AudioBuffer::AudioBuffer(Info *i, unsigned sz) : 
+AudioBase(i)
 {
 	size = sz;
 	buf = new char[size];
@@ -75,19 +76,19 @@ void AudioBuffer::leave(void)
 	mutex->leave();
 }
 
-void AudioBuffer::getBuffer(char *data, unsigned amount)
+ssize_t AudioBuffer::getBuffer(Encoded data, size_t amount)
 {
-	int left, copied;
+	size_t left, copied;
 
 	if(amount == 0)
-		return;
+		return 0;
 
 	enter();
 	if(len == 0)
 	{
 		memset(data, 0, amount);
 		leave();
-		return;
+		return (ssize_t)amount;
 	}
 
 	if(amount > len)
@@ -111,14 +112,15 @@ void AudioBuffer::getBuffer(char *data, unsigned amount)
 		start = (start + left) % size;
 	}
 	leave();
+	return (ssize_t)amount;
 }
 
-void AudioBuffer::putBuffer(const char *data, unsigned amount)
+ssize_t AudioBuffer::putBuffer(Encoded data, size_t amount)
 {
-	int nl, written, removed, offset;
+	size_t nl, written, removed, offset;
 
 	if(amount == 0)
-		return;
+		return 0;
 
 	enter();
 	nl = len + amount;
@@ -146,6 +148,7 @@ void AudioBuffer::putBuffer(const char *data, unsigned amount)
 		len += amount;
 	}
 	leave();
+	return (ssize_t)amount;
 }
 
 
