@@ -42,6 +42,16 @@
 
 using namespace ost;
 
+ssize_t AudioDevice::putBuffer(Encoded data, size_t count)
+{
+	return 0;
+}
+
+ssize_t AudioDevice::getBuffer(Encoded data, size_t count)
+{
+	return 0;
+}
+
 unsigned AudioDevice::bufMono(Linear samples, unsigned count)
 {
 	unsigned fill, index;
@@ -382,7 +392,7 @@ unsigned AudioStream::putMono(Linear buffer, unsigned frames)
 			continue;
 		}		
 		swapEndian(info, iobuf, info.framecount);
-		if(putBuffer(iobuf, info.framesize) < (signed)info.framesize)
+		if(putBuffer((Encoded)iobuf, info.framesize) < (signed)info.framesize)
 			break;
 		++copied;
 		buffer += info.framecount;
@@ -430,7 +440,7 @@ unsigned AudioStream::putStereo(Linear buffer, unsigned frames)
 			continue;
 		}
 		swapEndian(info, iobuf, info.framecount);
-		if(putBuffer(iobuf, info.framesize) < (signed)info.framesize)
+		if(putBuffer((Encoded)iobuf, info.framesize) < (signed)info.framesize)
 			break;
 		++copied;
 	}
@@ -571,7 +581,7 @@ unsigned AudioStream::getEncoded(AudioCodec *codec, Encoded addr, unsigned frame
 	Info ci;
 	unsigned count = 0;
 	unsigned bufsize = 0;
-	unsigned subcount, used = 0;
+	unsigned used = 0;
 	bool eof = false;
 
 	if(!codec)
